/// <reference types="bn.js" />
import { Connection, PublicKey } from "@solana/web3.js";
import { PDA } from "../pda";
import { AccountFetcher, CachedContent, CachedValue } from "./fetcher";
import { EscrowConfigData, KycCertData, TokenInfoData, TradeOrderData } from "../types";
import { BN } from "@project-serum/anchor";
export declare class EscrowFetcher {
    readonly fetcher: AccountFetcher;
    pda: PDA;
    connection: Connection;
    constructor(connection: Connection, pda: PDA, cache?: Record<string, CachedContent<CachedValue>>);
    getConfigData(): Promise<EscrowConfigData | null>;
    getTradeOrder(orderId: BN): Promise<TradeOrderData | null>;
    getTradesByStatus(tradeStatus: object): Promise<(TradeOrderData | null)[]>;
    getTradesByBuyerAddress(address: PublicKey): Promise<(TradeOrderData | null)[]>;
    getTradesBySellerAddress(address: PublicKey): Promise<(TradeOrderData | null)[]>;
    getTradeOrders(startOrderId: number, endOrderId?: number): Promise<(TradeOrderData | null)[]>;
    getAllTradeOrders(): Promise<(TradeOrderData | null)[]>;
    getKYCCertData(userPubkey: PublicKey): Promise<KycCertData | null>;
    getTokenInfoData(tokenMint: PublicKey): Promise<TokenInfoData | null>;
    isArbitrator(userPubkey: PublicKey): Promise<boolean>;
    refreshAll(): Promise<void>;
}
