/// <reference types="bn.js" />
import { BN, BorshAccountsCoder } from "@project-serum/anchor";
import { PublicKey } from "@solana/web3.js";
export declare enum AccountName {
    EscrowConfig = "EscrowConfig",
    TradeOrder = "TradeOrder",
    KycCert = "KycCert",
    ArbitratorCert = "ArbitratorCert",
    TokenInfo = "TokenInfo"
}
export declare const ESCROW_CODER: BorshAccountsCoder<string>;
export declare const sizeOf: (accountName: AccountName) => number;
export declare const ESCROW_CONFIG_SIZE: number;
export declare const TRADE_ORDER_SIZE: number;
export type EscrowConfigData = {
    configId: string;
    deployerAuthority: PublicKey;
    tradeConfigAuthority: PublicKey;
    amlPolicyAuthority: PublicKey;
    treasuryPubkey: PublicKey;
    currentId: BN;
    bondSize: BN;
    arbitratorCommission: BN;
    treasuryShare: BN;
    quota: BN[];
    paymentDuration: BN;
};
export type KycCertData = {
    level: number;
    totalTradedAmount: BN;
    bump: number;
};
export type TokenInfoData = {
    bump: number;
    tokenDecimal: number;
    oneRenecValueInToken: BN;
};
export declare const OrderState: {
    Awaiting: {
        awaiting: {};
    };
    Deposited: {
        deposited: {};
    };
    Disputed: {
        disputed: {};
    };
    Released: {
        released: {};
    };
    Canceled: {
        canceled: {};
    };
};
export declare const OrderSide: {
    Buy: {
        buy: {};
    };
    Sell: {
        sell: {};
    };
};
export declare const BondType: {
    Native: {
        native: {};
    };
    Spl: {
        spl: {};
    };
};
export declare const DisputeAction: {
    Release: {
        release: {};
    };
    Cancel: {
        cancel: {};
    };
};
export declare const CompensationAction: {
    NoCompensate: {
        noCompensate: {};
    };
    CompensateSeller: {
        compensateSeller: {};
    };
    CompensateBuyer: {
        compensateBuyer: {};
    };
};
export type TradeOrderData = {
    orderId: BN;
    orderIdSeed: number[];
    state: object;
    side: object;
    bondType: object;
    escrowConfig: PublicKey;
    sellerAuthority: PublicKey;
    sellerTokenAccount: PublicKey;
    buyerAuthority: PublicKey;
    buyerTokenAccount: PublicKey;
    tokenMint: PublicKey;
    tokenVault: PublicKey;
    nativeVault: PublicKey;
    bondAmount: BN;
    tokenAmount: BN;
    fiatAmount: BN;
    createdAt: BN;
    joinedAt: BN;
    finishedAt: BN;
    bump: number[];
};
export type ArbitratorCert = {
    bump: number;
};
